@@ -409,7 +409,7 @@
              :ppath use-path
              :child-pred child-pred})]
     (loop [pendq nil ;; a resolved child-lookup thunk to look at first
-           q (into (PersistentQueue/EMPTY) (map vector deps)) ;; queue of nodes or child-lookups
+           q (into PersistentQueue/EMPTY (map vector deps)) ;; queue of nodes or child-lookups
            version-map nil ;; track all seen versions of libs and which version is selected
            exclusions nil ;; tracks exclusions marked in the tree
            cut nil ;; tracks cuts made of child nodes based on exclusions
@@ -509,7 +509,7 @@
 (defn- make-tree
   [lib-map]
   (let [{roots false, nonroots true} (group-by #(-> % val :dependents boolean) lib-map)]
-    (loop [q (into (PersistentQueue/EMPTY) roots)
+    (loop [q (into PersistentQueue/EMPTY roots)
            remaining nonroots
            tree {}]
       (let [[lib coord :as node] (peek q)
@@ -787,17 +787,6 @@
       project-edn (assoc :project project-edn)
       extra-edn (assoc :extra extra-edn))))
 
-(defmacro ^:private in-project-dir
-  "If project deps.edn is not in the current dir, push project directory
-  into current directory context while creating basis. Local deps use paths
-  relative to project dir."
-  [project-deps & body]
-  `(if (and (instance? String ~project-deps)
-        (not (.equals dir/*the-dir* (.getParentFile (jio/file ~project-deps)))))
-     (dir/with-dir (.getParentFile (jio/file ~project-deps))
-        ~@body)
-     (do ~@body)))
-
 (defn create-basis
   "Create a basis from a set of deps sources and a set of aliases. By default, use
    root, user, and project deps and no argmaps (essentially the same classpath you get by
@@ -810,9 +799,10 @@
    subprocesses (tool, resolve-deps, make-classpath-map).
 
    Options:
+     :dir     - directory root path, defaults to current directory
      :root    - dep source, default = :standard
      :user    - dep source, default = :standard
-     :project - dep source, default = :standard (\"./deps.edn\")
+     :project - dep source, default = :standard (\"deps.edn\")
      :extra   - dep source, default = nil
      :aliases - coll of aliases, default = nil
 
@@ -832,8 +822,8 @@
     :libs - lib map, per resolve-deps
     :classpath - classpath map per make-classpath-map
     :classpath-roots - vector of paths in classpath order"
-  [{:keys [root user project extra aliases] :as params}]
-  (in-project-dir project
+  [{:keys [dir root user project extra aliases] :as params}]
+  (dir/with-dir (jio/file (or dir "."))
     (let [basis-config (cond-> nil
                          (contains? params :root) (assoc :root root)
                          (contains? params :project) (assoc :project project)
